==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/GroupRuleGroupAssignment.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Contains the &#x60;groupIds&#x60; array
 */
@ApiModel(description = "Contains the `groupIds` array")
@JsonPropertyOrder({ GroupRuleGroupAssignment.JSON_PROPERTY_GROUP_IDS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class GroupRuleGroupAssignment implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_GROUP_IDS = "groupIds";
    private List<String> groupIds = null;

    public GroupRuleGroupAssignment() {
    }

    public GroupRuleGroupAssignment groupIds(List<String> groupIds) {

        this.groupIds = groupIds;
        return this;
    }

    public GroupRuleGroupAssignment addgroupIdsItem(String groupIdsItem) {
        if (this.groupIds == null) {
            this.groupIds = new ArrayList<>();
        }
        this.groupIds.add(groupIdsItem);
        return this;
    }

    /**
     * Array of &#x60;groupIds&#x60; to which Users are added
     *
     * @return groupIds
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Array of `groupIds` to which Users are added")
    @JsonProperty(JSON_PROPERTY_GROUP_IDS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getGroupIds() {
        return groupIds;
    }

    @JsonProperty(JSON_PROPERTY_GROUP_IDS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGroupIds(List<String> groupIds) {
        this.groupIds = groupIds;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GroupRuleGroupAssignment groupRuleGroupAssignment = (GroupRuleGroupAssignment) o;
        return Objects.equals(this.groupIds, groupRuleGroupAssignment.groupIds);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(groupIds);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GroupRuleGroupAssignment {\n");
        sb.append("    groupIds: ").append(toIndentedString(groupIds)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/GroupRuleGroupAssignment.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Contains the &#x60;groupIds&#x60; array
 */
@ApiModel(description = "Contains the `groupIds` array")
@JsonPropertyOrder({ GroupRuleGroupAssignment.JSON_PROPERTY_GROUP_IDS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class GroupRuleGroupAssignment implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_GROUP_IDS = "groupIds";
    private List<String> groupIds = null;

    public GroupRuleGroupAssignment() {
    }

    public GroupRuleGroupAssignment groupIds(List<String> groupIds) {

        this.groupIds = groupIds;
        return this;
    }

    public GroupRuleGroupAssignment addgroupIdsItem(String groupIdsItem) {
        if (this.groupIds == null) {
            this.groupIds = new ArrayList<>();
        }
        this.groupIds.add(groupIdsItem);
        return this;
    }

    /**
     * Array of &#x60;groupIds&#x60; to which Users are added
     *
     * @return groupIds
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Array of `groupIds` to which Users are added")
    @JsonProperty(JSON_PROPERTY_GROUP_IDS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getGroupIds() {
        return groupIds;
    }

    @JsonProperty(JSON_PROPERTY_GROUP_IDS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGroupIds(List<String> groupIds) {
        this.groupIds = groupIds;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GroupRuleGroupAssignment groupRuleGroupAssignment = (GroupRuleGroupAssignment) o;
        return Objects.equals(this.groupIds, groupRuleGroupAssignment.groupIds);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(groupIds);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GroupRuleGroupAssignment {\n");
        sb.append("    groupIds: ").append(toIndentedString(groupIds)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
